@@ -14,7 +14,10 @@ no warnings qw/experimental::postderef experimental::signatures/;
 
 extends 'Config::Model::Backend::PlainFile';
 
+with 'Config::Model::Role::FileHandler';
+
 my $logger = get_logger("Backend::Dpkg::Root");
+my $user_logger = get_logger('User');
 
 my %dispatch = (
     patches => \&read_patch_series,
@@ -26,23 +29,13 @@ around read_hash => sub ( $orig, $self, $obj, $elt, $file, $check, $args ) {
     $logger->info("called for $elt ".$obj->location." file $file" );
     my $method = $dispatch{$elt} // $orig;
 
-    $self->$method( $obj, $elt, $file, $check, $args );
+    # $file was made from element name. This does not match the actual
+    # files, so we drop it
+    $self->$method( $obj, $elt, $check, $args );
 };
 
-# TODO: use a role provided by Config::Model
-sub cfg_path {
-    my $self = shift;
-    my %args = @_;
-    my $cfg_dir   = $args{config_dir};
-    my $dir
-        = $args{root}   ? path($args{root})->child($cfg_dir)
-        : ref($cfg_dir) ? $cfg_dir
-        :                 path( $cfg_dir);
-    return $dir;
-}
-
-sub read_install_files ( $self, $hash, $elt, $file, $check, $args ) {
-    my $dir = $self->cfg_path(%$args);
+sub read_install_files ( $self, $hash, $elt, $check, $args ) {
+    my $dir = $self->get_tuned_config_dir(%$args);
 
     return unless $dir->exists;
 
@@ -55,27 +48,19 @@ sub read_install_files ( $self, $hash, $elt, $file, $check, $args ) {
     }
 }
 
-sub read_patch_series ( $self, $hash, $elt, $file, $check, $args ) {
-    my $patch_dir = $self->cfg_path(%$args)->child("patches");
+sub read_patch_series ( $self, $hash, $elt, $check, $args ) {
+    my $patch_dir = $self->get_tuned_config_dir(%$args)->child("patches");
     $logger->info("Checking patches directory ($patch_dir)");
 
-    my $series_files = "$patch_dir/series";
+    return unless $patch_dir->is_dir;
 
-    return unless -d $patch_dir;
-    return unless -e $series_files;
+    my $series_files = $patch_dir->child("series");
+
+    return unless $series_files->is_file;
 
     $logger->info("Opening file $series_files");
-    my $ser_io = IO::File->new($series_files);
-
-    unless ( defined $ser_io ) {
-        my $msg = "Dpkg::Patch error, cannot read $series_files:$!";
-        Config::Model::Exception::User->throw( message => $msg )
-          if $check eq 'yes';
-        $logger->error($msg) if $check eq 'skip';
-    }
-
     # trigger element creation to read patch file_path
-    foreach my $pname ( $ser_io->getlines ) {
+    foreach my $pname ( $series_files->lines ) {
         chomp $pname;
 		$pname =~ s/#.*//; # skip comment
         next unless $pname =~ /\w/;    # skip empty lines
@@ -89,7 +74,7 @@ sub read_patch_series ( $self, $hash, $elt, $file, $check, $args ) {
                 $e -> rethrow();
             }
             else {
-                warn "Warning: Ignoring patch $pname: ", $e->message,"\n";
+                $user_logger->warn("Warning: Ignoring patch $pname: ", $e->message);
             }
             $hash->delete($pname);
         }
@@ -104,8 +89,6 @@ sub read_patch_series ( $self, $hash, $elt, $file, $check, $args ) {
             $logger->info("found patch $pname, stored in $location ($obj)");
         }
     }
-
-    $ser_io->close;
 }
 
 sub write {
@@ -118,20 +101,19 @@ sub write {
     # config_dir => /etc/foo',    # absolute path read
     # file       => 'foo.conf',   # file name
     # file_path  => './my_test/etc/foo/foo.conf'
-    # io_handle  => $io           # IO::File object
     # check      => yes|no|skip
 
     my $check = $args{check} || 'yes';
 
-    my $dir = $self->cfg_path(%args);
+    my $dir = $self->get_tuned_config_dir(%args);
 
-    mkpath( $dir, { mode => 0755 } ) unless -d $dir;
+    $dir->mkpath;
     my $node = $args{object};
     $logger->debug( "Dpkg write called on node ", $node->name );
 
     # write data from leaf element from the node
     foreach my $elt ( $node->get_element_name() ) {
-        my $file = path($dir)->child($elt);
+        my $file = $dir->child($elt);
 
         my $obj = $args{object}->fetch_element( name => $elt );
         my $type = $obj->get_type;
@@ -159,7 +141,7 @@ sub write {
             $file->chmod("a+x") if $elt eq 'rules';
         }
         elsif ($args{auto_delete} and $file->is_file and not $skip) {
-            warn "deleting $file";
+            $user_logger->warn("deleting $file");
             $file->remove;
         }
     }
@@ -226,23 +208,17 @@ In the case of C<list> element, each line of the file is a value of the list.
 Inherited from L<Config::Model::Backend::Any>. The constructor will be
 called by L<Config::Model::AutoRead>.
 
-=head2 read ( io_handle => ... )
+=head2 read
 
-Of all parameters passed to this read call-back, only C<io_handle> is
-used. This parameter must be L<IO::File> object already opened for
-read. 
+Read data from Dpkg files
 
-It can also be undef. In this case, C<read()> will return 0.
+When a file is read,  C<read()> returns 1.
 
-When a file is read,  C<read()> will return 1.
+=head2 write
 
-=head2 write ( io_handle => ... )
+Write Dpkg data to files.
 
-Of all parameters passed to this write call-back, only C<io_handle> is
-used. This parameter must be L<IO::File> object already opened for
-write. 
-
-C<write()> will return 1.
+C<write()> returns 1.
 
 =head1 AUTHOR
 
