@@ -31,14 +31,15 @@ sub read {
     # config_dir => /etc/foo',    # absolute path 
     # file       => 'foo.conf',   # file name
     # file_path  => './my_test/etc/foo/foo.conf' 
-    # io_handle  => $io           # IO::File object
-    # check      => yes|no|skip  
+    # check      => yes|no|skip
 
-    return 0 unless defined $args{io_handle} ;
+    my $fp = $args{file_path};
 
-    $logger->info("Parsing $args{file_path}");
+    return 0 unless defined $fp and $fp->is_file ;
+
+    $logger->info("Parsing $fp");
     # load dpkgctrl file
-    my $c = $self -> parse_dpkg_file ($args{file_path}, $args{io_handle}, $args{check}, 1 ) ;
+    my $c = $self -> parse_dpkg_file ($fp, $args{check}, 1 ) ;
 
     # fix Debian #735000: ask for infos for all packages not in cache in one go.
     $self->fill_package_cache ($c);
@@ -192,25 +193,21 @@ sub write {
     # config_dir => /etc/foo',    # absolute path 
     # file       => 'foo.conf',   # file name
     # file_path  => './my_test/etc/foo/foo.conf' 
-    # io_handle  => $io           # IO::File object
-
-    croak "Undefined file handle to write"
-      unless defined $args{io_handle} ;
 
     my $node = $args{object} ;
-    my $ioh  = $args{io_handle} ;
     my @sections = [ $self-> package_spec($node->fetch_element('source')) ];
 
     my $binary_hash = $node->fetch_element('binary') ;
     foreach my $binary_name ( $binary_hash -> fetch_all_indexes ) {
         my $ref = [ Package => $binary_name ,
                     $self->package_spec($binary_hash->fetch_with_id($binary_name)) ];
-        
+
         push @sections, $ref ;
     }
 
-    $self->write_dpkg_file($ioh, \@sections,",\n" ) ;
-    
+    my $res = $self->write_dpkg_file(\@sections,",\n" ) ;
+    $args{file_path}->spew_utf8($res);
+
     return 1;
 }
 
@@ -267,23 +264,13 @@ All C<control> files keyword are read in a case-insensitive manner.
 Inherited from L<Config::Model::Backend::Any>. The constructor will be
 called by L<Config::Model::AutoRead>.
 
-=head2 read ( io_handle => ... )
+=head2 read
 
-Of all parameters passed to this read call-back, only C<io_handle> is
-used. This parameter must be L<IO::File> object already opened for
-read. 
+Read control file and return 1.
 
-It can also be undef. In this case, C<read()> will return 0.
+=head2 write
 
-When a file is read,  C<read()> will return 1.
-
-=head2 write ( io_handle => ... )
-
-Of all parameters passed to this write call-back, only C<io_handle> is
-used. This parameter must be L<IO::File> object already opened for
-write. 
-
-C<write()> will return 1.
+Write data to control file and return 1.
 
 =head1 AUTHOR
 
