@@ -23,6 +23,7 @@ use File::Path;
 use Log::Log4perl qw(get_logger :levels);
 
 my $logger = get_logger("Backend::Dpkg::Copyright") ;
+my $user_logger = get_logger('User');
 
 my %store_dispatch = (
     list    => 'store_section_list_element',
@@ -40,17 +41,18 @@ sub read {
     # config_dir => /etc/foo',    # absolute path 
     # file       => 'foo.conf',   # file name
     # file_path  => './my_test/etc/foo/foo.conf' 
-    # io_handle  => $io           # IO::File object
     # check      => yes|no|skip
 
-    return 0 unless defined $args{io_handle} ;
+    my $fp = $args{file_path};
+
+    return 0 unless defined $fp and $fp->is_file ;
 
     my $check = $args{check} || 'yes';
 
-    $logger->info("Parsing $args{file_path}");
+    $logger->info("Parsing $fp");
 
     # load dpkgctrl file
-    my $c = $self -> parse_dpkg_file ($args{file_path}, $args{io_handle}, $check ) ;
+    my $c = $self -> parse_dpkg_file ($fp, $check ) ;
     return 0 unless @$c ; # no sections in file
 
     my $root = $args{object} ;
@@ -78,7 +80,7 @@ sub read {
         # Some people use 'File' to declare copyright info for a single file.
         # While this is correct grammatically, it tends to be PITA
         if (my $file_section = delete $section{file}) {
-            warn("copyright line $section_line: section 'File' is converted in 'Files' section (mind the plural)\n");
+            $user_logger->warn("copyright line $section_line: section 'File' is converted in 'Files' section (mind the plural)\n");
             $file_section->[0][2] = 'changed file section into files section' ;
             $section{files} //= $file_section ; # no clobber of good section
         }
@@ -88,18 +90,18 @@ sub read {
             ) {
             # Some legacy files can have a header and one paragraph with License tag
             # more often than not, this is an implied "File: *"  section
-            my $str = "Missing 'Files:' specification in section starting line $section_line. Use cme with -force option to load";
+            my $str = "Missing 'Files:' specification in section starting line $section_line. Use cme with -force option to load.";
             Config::Model::Exception::Syntax 
                 -> throw ( object => $self, error => $str, parsed_line => $section_line ) 
                     if $check eq 'yes' ;
-            warn("$str Adding 'Files: *' spec\n") ;
+            $user_logger->warn("$str Adding 'Files: *' spec\n") ;
             # the 3rd element is used to tell root node that read data was 
             # altered and needs to be written back
             $section{files} = [ ['*', $section_line, 'created missing File:* section' ] ];
         }
 
         if (defined $section{licence}) {
-            warn("copyright line $section_line: Converting UK spelling for license in US spelling\n");
+            $user_logger->warn("copyright line $section_line: Converting UK spelling for license in US spelling\n");
             $section{license} = delete $section{licence} ;# FIXME: use notify_change
             $section{license}[0][2] = 'changed uk spelling for license (was licence)'; # is altered
         }
@@ -115,7 +117,7 @@ sub read {
                     $logger->debug("Found Files paragraph line $l, $a_str($v)");
                 }
                 if ($v =~ /,/) {
-                    $logger->warn("Found comma in Files line $l, cleaning up");
+                    $user_logger->warn("Found comma in Files line $l, cleaning up");
                     $v =~ s/,+/ /g;
                 }
                 $v =~ s/(?<=\w)[ \t]+/ /g; # cleanup spacing between words
@@ -155,7 +157,7 @@ sub read {
                     parsed_line => $section_line 
                 );
             }
-            $logger->warn("copyright line $section_line: Dropping unknown paragraph");
+            $user_logger->warn("copyright line $section_line: Dropping unknown paragraph");
         }
     }
 
@@ -261,7 +263,7 @@ sub append_text_no_synopsis ($self, $logger_param, $object, $check, $v_ref) {
     my $old = $object->fetch(check => 'no');
     my @new_ref = $v_ref->@*;
     if ($old) {
-        $logger->warn("double entry for ",$object->name,", appending value");
+        $user_logger->warn("double entry for ",$object->name,", appending value");
         unshift @new_ref, [ $old, 0, ''];
     }
 
@@ -287,7 +289,7 @@ sub _store_file_info ($self,$section, $object, $target_name,$key, $check, $v_ref
 
 sub _store_license_info ($self, $lic_node, $key, $check, $v_ref ) {
     if ( $key =~ /licence/ ) {
-        $logger->warn( "Found UK spelling: $key will be converted to License" );
+        $user_logger->warn( "Found UK spelling: $key will be converted to License" );
         $lic_node->notify_change(
             note   => 'change UK spelling to US spelling',
             really => 1
@@ -326,13 +328,8 @@ sub write {
     # config_dir => /etc/foo',    # absolute path
     # file       => 'foo.conf',   # file name
     # file_path  => './my_test/etc/foo/foo.conf'
-    # io_handle  => $io           # IO::File object
-
-    croak "Undefined file handle to write"
-      unless defined $args{io_handle};
 
     my $node = $args{object};
-    my $ioh  = $args{io_handle};
 
     my $my_leaf_cb = sub {
         my ( $scanner, $data_ref, $node, $element_name, $key, $leaf_object ) =
@@ -434,7 +431,8 @@ sub write {
     unshift @sections, \@section1 ;
     
     #use Data::Dumper ; print Dumper \@sections ; exit ;
-    $self->write_dpkg_file( $ioh, \@sections, "\n" );
+    my $res = $self->write_dpkg_file( \@sections, "\n" );
+    $args{file_path}->spew_utf8($res);
 
     return 1;
 }
@@ -466,23 +464,13 @@ license information in Debian source package format.
 Inherited from L<Config::Model::Backend::Any>. The constructor will be
 called by L<Config::Model::AutoRead>.
 
-=head2 read ( io_handle => ... )
+=head2 read
 
-Of all parameters passed to this read call-back, only C<io_handle> is
-used. This parameter must be L<IO::File> object already opened for
-read. 
+Read data from copyright file and return 1.
 
-It can also be undef. In this case, C<read()> will return 0.
+=head2 write
 
-When a file is read,  C<read()> will return 1.
-
-=head2 write ( io_handle => ... )
-
-Of all parameters passed to this write call-back, only C<io_handle> is
-used. This parameter must be L<IO::File> object already opened for
-write. 
-
-C<write()> will return 1.
+Write data to copyright file and return 1.
 
 =head1 AUTHOR
 
