@@ -45,11 +45,8 @@ sub read {
     # config_dir => /etc/foo',    # absolute path
     # file       => 'foo.conf',   # file name
     # file_path  => './my_test/etc/foo/foo.conf'
-    # io_handle  => $io           # IO::File object
     # check      => yes|no|skip
 
-    # io_handle is not defined as no file is specified in model
-
     my $cfg_dir   = $args{config_dir};
     my $patch_dir = $self->cfg_path(%args);
 
@@ -167,19 +164,13 @@ sub write {
     # config_dir => /etc/foo',    # absolute path
     # file       => 'foo.conf',   # file name
     # file_path  => './my_test/etc/foo/foo.conf'
-    # io_handle  => $io           # IO::File object
-
-    # io_handle is not defined as no file is specified in model
 
     my $check     = $args{check};
     my $node      = $args{object};
 
     my $patch_file =     $self->{patch_file} ;
     $logger->info("Writing patch $patch_file");
-
-    my $io = $patch_file->openw_utf8 || Config::Model::Exception::Syntax->throw(
-        message => "cannot write patch $patch_file"
-    );
+    my $res = '';
 
     # first: write Description or Subject (where the subuject body is written
     # outside the structured part -- as required by dep-3)
@@ -192,20 +183,20 @@ sub write {
     }
     elsif ($description_body) {
         my $to_write = $synopsis . "\n" . $description_body ;
-        $io->print("Description: ");
-        $self->write_dpkg_text($io, $to_write) ;
+        $res .= "Description: ";
+        $res .= $self->write_dpkg_text($to_write) ;
     }
     elsif ($subject_body) {
         # DEP-3: When Subject is used, it is expected that the
         # long description is outside of the structured
         # fields.
-        $io->print("Subject: ");
-        $self->write_dpkg_text($io, $synopsis) ;
+        $res .= "Subject: ";
+        $res .= $self->write_dpkg_text($synopsis) ;
     }
     else {
         # no description body, write only synopsis
-        $io->print("Description: ");
-        $self->write_dpkg_text($io, $synopsis) ;
+        $res .= "Description: ";
+        $res .= $self->write_dpkg_text($synopsis) ;
     }
 
     # second: write all headers
@@ -222,19 +213,19 @@ sub write {
             next unless defined $v and $v;
             next if grep {$elt eq $_} qw/Description Subject Synopsis diff/;
 
-            $io->print("$elt: ");
-            $self->write_dpkg_text($io,$v) ;
+            $res .= "$elt: ";
+            $res .= $self->write_dpkg_text($v) ;
         }
     }
 
     # third: write subect body
     if ($subject_body) {
-        $io->print($subject_body."\n");
+        $res .= $subject_body."\n";
     }
 
-    $io->print($node->fetch_element_value('diff')) ;
-    $io->close;
+    $res .= $node->fetch_element_value('diff');
 
+    $patch_file->spew_utf8($res);
     return 1;
 }
 
@@ -264,23 +255,13 @@ All C<Patch> files keyword are read in a case-insensitive manner.
 Inherited from L<Config::Model::Backend::Any>. The constructor will be
 called by L<Config::Model::AutoRead>.
 
-=head2 read ( io_handle => ... )
+=head2 read
 
-Of all parameters passed to this read call-back, only C<io_handle> is
-used. This parameter must be L<IO::File> object already opened for
-read. 
+Read data from patch file.
 
-It can also be undef. In this case, C<read()> will return 0.
+=head2 write
 
-When a file is read,  C<read()> will return 1.
-
-=head2 write ( io_handle => ... )
-
-Of all parameters passed to this write call-back, only C<io_handle> is
-used. This parameter must be L<IO::File> object already opened for
-write. 
-
-C<write()> will return 1.
+Write data to patch file
 
 =head1 AUTHOR
 
