@@ -15,7 +15,6 @@ use Data::Dumper;
 
 use Config::Model::DumpAsData;
 use Dpkg::Copyright::Scanner qw/scan_files __squash __pack_files __pack_copyright __create_tree_leaf_from_paths/;
-use Software::LicenseUtils;
 use Scalar::Util qw/weaken/;
 use Storable qw/dclone/;
 
@@ -345,31 +344,6 @@ sub _prune_old_dirs ($self, $h, $old_dirs, $path = [] ) {
     }
 }
 
-
-sub fill_global_license ($self, $l, $text) {
-
-    #$self->_say( "Adding global license $l");
-    # handle the case where license is something like GPL-2 or GPL-3
-    my @names = $l =~ / or / ? split / or /, $l : ($l);
-
-    # try to fill text of a known license
-    foreach my $name (@names) {
-        my $license_object ;
-        eval {
-            $license_object = Software::LicenseUtils->new_from_short_name( {
-                short_name => $name,
-                holder => 'X. Ample'
-            }) ;
-        };
-        if ($license_object) {
-            $self->load(qq!License:$name!); # model will fill the text
-        }
-        else {
-            $self->load(qq!License:$name text:"$text"!);
-        }
-    }
-}
-
 1;
 
 __END__
