@@ -35,7 +35,7 @@ my $madison_endpoint = "https://$madison_host/madison";
 
 # list of virtual packages
 # See https://www.debian.org/doc/packaging-manuals/virtual-package-names-list.txt
-# updated from 30 Jul 2014 version
+# updated from 08 Jan 2017 version
 my @virtual_list = qw/
  adventure
  audio-mixer
@@ -137,15 +137,15 @@ my @virtual_list = qw/
 /;
 
 # other less official virtual packages
-push @virtual_list,
-  qw/
-		libgl-dev
-		libtiff-dev
-        libuv-dev
-		ruby-interpreter
-        ssh-client
-        ssh-server
-	/;
+push @virtual_list, qw/
+ libgl-dev
+ libqt5opengl5-desktop-dev
+ libtiff-dev
+ libuv-dev
+ ruby-interpreter
+ ssh-client
+ ssh-server
+/;
 
 my %virtual_hash = map {( $_ => 1); } @virtual_list;
 
@@ -279,7 +279,7 @@ arch: / (any |alpha|amd64
          |avr32 |hppa |i386 |ia64 |lpia |m32r |m68k
          |mips(el|64el|64)?
          |powerpc(el|spe)?
-         |ppc64\b |ppc64el |s390 |s390x
+         |ppc64\b |ppc64el |s390x?
          |sh3\b |sh3eb |sh4\b |sh4eb |sparc\b |sparc64 |x32 )
         (?=(\]| ))
       /x
@@ -325,7 +325,7 @@ sub check_dependency {
 
     # to get package list in json format ( 'f' option)
     # wget -q -O - 'https://api.ftp-master.debian.org/madison?package=perl-doc&f'
-    #  MOJO_USERAGENT_DEBUG=0 mojo get 'https://api.ftp-master.debian.org/madison?package=perl-doc&f'
+    # mojo get 'https://api.ftp-master.debian.org/madison?package=perl-doc&f'
 
     my @dep_chain ;
     if (defined $value) {
@@ -380,7 +380,7 @@ sub check_debhelper_version {
     $logger->debug("checking '$dep_string' with lintian");
 
     # try to create compat_obj, but do not try twice (hence the exists test)
-    # compat_obj will be undef with 'cme edit dpkg-control'
+    # compat_obj is undef when running with 'cme edit dpkg-control'
     if (not exists $self->{_compat_obj} ) {
         # using mode loose because debian-control model can be used alone
         # and compat is outside of debian-control
@@ -392,20 +392,21 @@ sub check_debhelper_version {
 
     my $compat_value = $self->{_compat_obj}->fetch;
 
-    my $min_dep = Lintian::Relation->new("debhelper ( >= $compat_value)") ;
+    # lintian does not accept space after the version number
+    my $min_dep = Lintian::Relation->new("debhelper ( >= $compat_value~)") ;
 
     if ($lintian_dep->implies ($min_dep)) {
         $logger->debug($dep_string." -> ".$lintian_dep->unparse." implies ". $min_dep->unparse);
         return;
     }
 
-    $logger->debug("'$dep_string' does not imply debhelper >= $compat_value");
+    $logger->debug("'$dep_string' does not imply debhelper >= $compat_value~");
 
     # $show_rel avoids undef warnings
     my $show_rel = join(' ', map { $_ || ''} ($oper, $dep_v));
-    my $msg = "should be (>= $compat_value) not ($show_rel) because compat is $compat_value" ;
+    my $msg = "should be (>= $compat_value~) not ($show_rel) because compat is $compat_value" ;
     if ($apply_fix) {
-        $dep_info->{dep} = [ '>=', $compat_value] ; # notify_change called in check_value
+        $dep_info->{dep} = [ '>=', $compat_value.'~' ] ; # notify_change called in check_value
         $logger->info("fixed debhelper dependency from "
             ."$dep_name $show_rel -> ".$min_dep->unparse." (for compat $compat_value)");
         push $msgs->@*, $msg;
