@@ -41,17 +41,21 @@ For details, see L<section 5.7 of Debian policy|https://www.debian.org/doc/debia
           'formula' => 'my $name = $ENV{DEBFULLNAME};
 my $email = $ENV{DEBEMAIL} ;
 my $ret;
-$ret = "$name <$email>" if defined $name and defined $email;
+$ret = "$name <$email>" if $name and $email;
 $ret;',
           'use_eval' => '1'
         },
         'description' => 'The package maintainer\'s name and email address. The name must come first, then the email address inside angle brackets <> (in RFC822 format).
 
 If the maintainer\'s name contains a full stop then the whole field will not work directly as an email address due to a misfeature in the syntax specified in RFC822; a program using this field as an address must check for this and correct the problem if necessary (for example by putting the name in round brackets and moving it to the end, and bringing the email address forward). ',
-        'mandatory' => '1',
         'summary' => 'package maintainer\'s name and email address',
         'type' => 'leaf',
-        'value_type' => 'uniline'
+        'value_type' => 'uniline',
+        'warn_unless_match' => {
+          '@' => {
+            'msg' => 'Maintainer is empty or is not an email address'
+          }
+        }
       },
       'Uploaders',
       {
@@ -64,7 +68,7 @@ If the maintainer\'s name contains a full stop then the whole field will not wor
       },
       'Standards-Version',
       {
-        'default' => '4.1.3',
+        'class' => 'Config::Model::Dpkg::Control::Source::StandardVersion',
         'description' => 'This field indicates the Debian policy version number this package complies to.
 
 Before updating this field, please read L<upgrading-checklist|https://www.debian.org/doc/debian-policy/#document-upgrading-checklist>
@@ -76,8 +80,8 @@ to know what changes came with a new policy version number and apply the require
         'warn_unless' => {
           'current' => {
             'code' => '$_ eq $self->_fetch_std;',
-            'fix' => '$_ = undef; # restore default value',
-            'msg' => 'Current standards version is \'$std_value\'. Please read file:///usr/share/doc/debian-policy/upgrading-checklist.txt.gz to check what changes need to applied to your package to upgrade it from standard version \'$_\' to \'$std_value\'.
+            'fix' => '$_ = $self->_fetch_std; # restore default value',
+            'msg' => 'Current standards version is \'$std_value\'. Please read https://www.debian.org/doc/debian-policy/#document-upgrading-checklist for the changes that may be needed on your package to upgrade it from standard version \'$_\' to \'$std_value\'.
 '
           }
         }
@@ -90,7 +94,7 @@ grouped further into sections to simplify handling.
 
 The archive area and section for each package should be specified in
 the package\'s Section control record (see 
-L<Section 5.6.5|http://www.debian.org/doc/debian-policy/#section>).
+L<Section 5.6.5|https://www.debian.org/doc/debian-policy/#section>).
 However, the maintainer of the Debian archive may override
 this selection to ensure the consistency of the Debian
 distribution. The Section field should be of the form:
@@ -135,7 +139,7 @@ area/section if the package is in the contrib or non-free archive areas.
       },
       'Testsuite',
       {
-        'description' => 'Enable a test suite to be used with this package. For more details see L<README.package-tests.rst|https://anonscm.debian.org/cgit/autopkgtest/autopkgtest.git/plain/doc/README.package-tests.rst>',
+        'description' => 'Enable a test suite to be used with this package. For more details see L<README.package-tests.rst|https://salsa.debian.org/ci-team/autopkgtest/blob/master/doc/README.package-tests.rst>',
         'migrate_from' => {
           'formula' => '$xs_testsuite',
           'variables' => {
@@ -178,7 +182,7 @@ $_ = $str ? \'autopkgtest-pkg-\'.$str : undef;',
       {
         'default' => '0',
         'description' => 'Read the full description from 
-L<section 5.10.5|http://www.debian.org/doc/manuals/developers-reference/pkgs.html#non-free-buildd> 
+L<section 5.10.5|https://www.debian.org/doc/manuals/developers-reference/pkgs.html#non-free-buildd> 
 in Debian developer reference.',
         'level' => 'hidden',
         'summary' => 'Allow automatic build of non-free or contrib package',
@@ -398,8 +402,16 @@ A package including binaries from grub2 and loadlin would have this field in its
       {
         'compute' => {
           'allow_override' => '1',
-          'formula' => '  $maintainer =~ /(pkg-perl)/                       ? "https://anonscm.debian.org/cgit/$1/packages/$pkgname.git"
-: $maintainer =~ /(pkg-(?:ruby-extras|javascript))/ ? "https://anonscm.debian.org/cgit/$1/$pkgname.git"
+          'formula' => '  $pkgname =~ /r-cran-/ ? "https://salsa.debian.org/r-pkg-team/$pkgname"
+: $maintainer =~ /pkg-perl/ ? "https://salsa.debian.org/perl-team/modules/packages/$pkgname"
+: $maintainer =~ /pkg-ruby-extras/ ? "https://salsa.debian.org/ruby-team/$pkgname"
+: $maintainer =~ /pkg-javascript/ ? "https://salsa.debian.org/js-team/$pkgname"
+: $maintainer =~ /debian-med-packaging/ ? "https://salsa.debian.org/med-team/$pkgname"
+: $maintainer =~ /team\\@neuro.debian.net/ ? "https://salsa.debian.org/neurodebian-team/$pkgname"
+: $maintainer =~ /debian-science-maintainers/ ? "https://salsa.debian.org/science-team/$pkgname"
+: $maintainer =~ /pkg-phototools-devel/ ? "https://salsa.debian.org/debian-phototools-team/$pkgname"
+: $maintainer =~ /pkg-java-maintainers/ ? "https://salsa.debian.org/java-team/$pkgname"
+: $maintainer =~ /r-pkg-team/ ? "https://salsa.debian.org/r-pkg-team/$pkgname"
 :                                                     undef ;',
           'use_eval' => '1',
           'variables' => {
@@ -407,7 +419,7 @@ A package including binaries from grub2 and loadlin would have this field in its
             'pkgname' => '- Source'
           }
         },
-        'description' => 'Value of this field should be a http:// URL pointing to a web-browsable copy of the Version Control System repository used to maintain the given package, if available.
+        'description' => 'Value of this field should be a https:// URL pointing to a web-browsable copy of the Version Control System repository used to maintain the given package, if available.
 
 The information is meant to be useful for the final user, willing to browse the latest work done on the package (e.g. when looking for the patch fixing a bug tagged as pending in the bug tracking system). ',
         'match' => '^https?://',
@@ -416,13 +428,9 @@ The information is meant to be useful for the final user, willing to browse the
         'value_type' => 'uniline',
         'warn_unless' => {
           'debian-uri' => {
-            'code' => '!defined $_ or ! /debian.org/ or m{^https?://anonscm.debian.org/(viewvc|cgit|loggerhead)} ;',
-            'fix' => 's{https?://svn\\.debian\\.org/\\w+svn/}{http://anonscm.debian.org/viewvc/};
-s{http://git.debian.org/\\?p=}{https://anonscm.debian.org/cgit/};
-s{http://anonscm.debian.org/gitweb/\\?p=}{https://anonscm.debian.org/cgit/};
-s{(https://anonscm.debian.org/cgit/.+);a=summary}{$1};
-s{http://bzr.debian.org/loggerhead/}{http://anonscm.debian.org/loggerhead/};',
-            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
+            'code' => '!defined $_ or ! /debian.org/ or m{^https://salsa.debian.org/};',
+            'fix' => '$_ = undef; # let the correct value be set by compute setup',
+            'msg' => 'URL is not the canonical one for repositories hosted on Debian infrastructure.'
           }
         }
       },
@@ -434,11 +442,11 @@ The information is meant to be useful for a user knowledgeable in the given Vers
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline',
-        'warn_unless' => {
+        'warn_if' => {
           'debian-uri' => {
-            'code' => '!defined $_ or ! /debian.org/ or m{^http://anonscm.debian.org/arch} ;',
-            'fix' => 's!http://[\\w\\.-]+/(arch/)*!http://anonscm.debian.org/arch/!;',
-            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
+            'code' => 'defined $_ and /debian.org/;',
+            'fix' => '$_ = undef;',
+            'msg' => 'URL is invalid, no support for this Vcs on Debian infrastructure anymore.'
           }
         }
       },
@@ -450,12 +458,11 @@ The information is meant to be useful for a user knowledgeable in the given Vers
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline',
-        'warn_unless' => {
+        'warn_if' => {
           'debian-uri' => {
-            'code' => '!defined $_ or ! /debian.org/ or m{^http://anonscm.debian.org/bzr/} ;',
-            'fix' => 's{http://\\w+.debian.org/(bzr/)*}{http://anonscm.debian.org/bzr/};
-',
-            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
+            'code' => 'defined $_ and /debian.org/;',
+            'fix' => '$_ = undef;',
+            'msg' => 'URL is invalid, no support for this Vcs on Debian infrastructure anymore.'
           }
         }
       },
@@ -467,12 +474,11 @@ The information is meant to be useful for a user knowledgeable in the given Vers
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline',
-        'warn_unless' => {
+        'warn_if' => {
           'debian-uri' => {
-            'code' => '!defined $_ or ! /debian.org/ or m{\\@anonscm.debian.org:/cvs/} ;',
-            'fix' => 's{\\@(?:cvs.alioth|anonscm)\\.debian\\.org:/cvsroot/}
-                      {\\@anonscm.debian.org:/cvs/}',
-            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
+            'code' => 'defined $_ and /debian.org/;',
+            'fix' => '$_ = undef;',
+            'msg' => 'URL is invalid, no support for this Vcs on Debian infrastructure anymore.'
           }
         }
       },
@@ -489,8 +495,16 @@ The information is meant to be useful for a user knowledgeable in the given Vers
       {
         'compute' => {
           'allow_override' => '1',
-          'formula' => '  $maintainer =~ /(pkg-perl)/                        ? "https://anonscm.debian.org/git/$1/packages/$pkgname.git"
-: $maintainer =~ /(pkg-(?:ruby-extras|javascript))/  ? "https://anonscm.debian.org/git/$1/$pkgname.git"
+          'formula' => '  $pkgname =~ /r-cran-/ ? "https://salsa.debian.org/r-pkg-team/$pkgname.git"
+: $maintainer =~ /pkg-perl/                        ? "https://salsa.debian.org/perl-team/modules/packages/$pkgname.git"
+: $maintainer =~ /pkg-ruby-extras/ ? "https://salsa.debian.org/ruby-team/$pkgname.git"
+: $maintainer =~ /pkg-javascript/ ? "https://salsa.debian.org/js-team/$pkgname.git"
+: $maintainer =~ /debian-med-packaging/ ? "https://salsa.debian.org/med-team/$pkgname.git"
+: $maintainer =~ /team\\@neuro.debian.net/ ? "https://salsa.debian.org/neurodebian-team/$pkgname.git"
+: $maintainer =~ /debian-science-maintainers/ ? "https://salsa.debian.org/science-team/$pkgname.git"
+: $maintainer =~ /pkg-phototools-devel/ ? "https://salsa.debian.org/debian-phototools-team/$pkgname.git"
+: $maintainer =~ /pkg-java-maintainers/ ? "https://salsa.debian.org/java-team/$pkgname.git"
+: $maintainer =~ /r-pkg-team/ ? "https://salsa.debian.org/r-pkg-team/$pkgname.git"
 :                                                    \'\' ;',
           'use_eval' => '1',
           'variables' => {
@@ -515,10 +529,9 @@ The information is meant to be useful for a user knowledgeable in the given Vers
         },
         'warn_unless' => {
           'debian-uri' => {
-            'code' => '!defined $_ or ! /debian.org/ or m{^https://anonscm.debian.org/git/(?!git/)};',
-            'fix' => 's!http://[\\w\\.-]+/(git/)*!https://anonscm.debian.org/git/!;
-s!git://[\\w\\.-]+/(git/)?!https://anonscm.debian.org/git/!;',
-            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
+            'code' => '!defined $_ or ! /debian.org/ or m{^https://salsa.debian.org/};',
+            'fix' => '$_ = undef; # let the correct value be set by compute setup',
+            'msg' => 'URL is not the canonical one for repositories hosted on Debian infrastructure.'
           }
         }
       },
@@ -530,11 +543,11 @@ The information is meant to be useful for a user knowledgeable in the given Vers
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline',
-        'warn_unless' => {
+        'warn_if' => {
           'debian-uri' => {
-            'code' => '!defined $_ or ! /debian.org/ or m{^http://anonscm.debian.org/hg/};',
-            'fix' => 's{http://\\w+.debian.org/(hg/)*}{http://anonscm.debian.org/hg/};',
-            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
+            'code' => 'defined $_ and /debian.org/;',
+            'fix' => '$_ = undef;',
+            'msg' => 'URL is invalid, no support for this Vcs on Debian infrastructure anymore.'
           }
         }
       },
@@ -555,17 +568,17 @@ The information is meant to be useful for a user knowledgeable in the given Vers
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline',
-        'warn_unless' => {
+        'warn_if' => {
           'debian-uri' => {
-            'code' => '!defined $_ or ! /debian.org/ or m{^svn://anonscm.debian.org/} ;',
-            'fix' => 's{svn://\\w+.debian.org/(svn/)*}{svn://anonscm.debian.org/};',
-            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
+            'code' => 'defined $_ and /debian.org/;',
+            'fix' => '$_ = undef;',
+            'msg' => 'URL is invalid, no support for this Vcs on Debian infrastructure anymore.'
           }
         }
       },
       'DM-Upload-Allowed',
       {
-        'description' => 'If this field is present, then any Debian Maintainers listed in the Maintainer or Uploaders fields may upload the package directly to the Debian archive.  For more information see the "Debian Maintainer" page at the Debian Wiki - http://wiki.debian.org/DebianMaintainer',
+        'description' => 'If this field is present, then any Debian Maintainers listed in the Maintainer or Uploaders fields may upload the package directly to the Debian archive.  For more information see the "Debian Maintainer" page at the Debian Wiki - https://wiki.debian.org/DebianMaintainer',
         'match' => 'yes',
         'status' => 'deprecated',
         'summary' => 'The package may be uploaded by a Debian Maintainer',
@@ -585,7 +598,7 @@ The information is meant to be useful for a user knowledgeable in the given Vers
       },
       'X-Python-Version',
       {
-        'description' => 'This field specifies the versions of Python (not versions of Python 3) supported by the source package.  When not specified, they default to all currently supported Python (or Python 3) versions. For more detail, See L<python policy|http://www.debian.org/doc/packaging-manuals/python-policy/ch-module_packages.html#s-specifying_versions>',
+        'description' => 'This field specifies the versions of Python (not versions of Python 3) supported by the source package.  When not specified, they default to all currently supported Python (or Python 3) versions. For more detail, See L<python policy|https://www.debian.org/doc/packaging-manuals/python-policy/ch-module_packages.html#s-specifying_versions>',
         'migrate_from' => {
           'formula' => 'my $old = $xspython ;
 my $new ;
@@ -615,7 +628,7 @@ $new ;',
       },
       'X-Python3-Version',
       {
-        'description' => 'This field specifies the versions of Python 3 supported by the package. For more detail, See L<python policy|http://www.debian.org/doc/packaging-manuals/python-policy/ch-module_packages.html#s-specifying_versions>',
+        'description' => 'This field specifies the versions of Python 3 supported by the package. For more detail, See L<python policy|https://www.debian.org/doc/packaging-manuals/python-policy/ch-module_packages.html#s-specifying_versions>',
         'summary' => 'supported versions of Python3 ',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -629,10 +642,11 @@ supported by the library',
         'value_type' => 'uniline',
         'warp' => {
           'follow' => {
-            'section' => '- Section'
+            'maintainer' => '- Maintainer',
+            'source' => '- Source'
           },
           'rules' => [
-            '$section =~ m!ruby$!',
+            '$maintainer =~ m!Debian Ruby!i or $source =~ /^ruby/',
             {
               'level' => 'normal'
             }
