@@ -68,6 +68,10 @@ you can fill like the C<Bug> field.',
           'type' => 'leaf',
           'value_type' => 'uniline',
           'warn_if_match' => {
+            '^#?\\d+$' => {
+              'fix' => 's!^!https://bugs.debian.org/!;',
+              'msg' => 'This field should contain an URL to Debian BTS and not just a bug number'
+            },
             'https://bugs.debian.org/cgi-bin/bugreport\\.cgi\\?bug=' => {
               'fix' => 's!/cgi-bin/bugreport\\.cgi\\?bug=!/!',
               'msg' => 'You should use the simplified form of BTS URL'
