@@ -1,25 +1,33 @@
 use Data::Dumper;
 use IO::File;
+use Path::Tiny;
+use Lintian::Data;
+use Lintian::Profile;
 
-$conf_file_name = "control";
-$conf_dir       = 'debian';
-$model_to_test  = "Dpkg::Control";
+use strict;
+use warnings;
 
-eval { require AptPkg::Config ;} ;
-$skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
+our $conf_file_name = "control";
+our $conf_dir       = 'debian';
+our $model_to_test  = "Dpkg::Control";
+
+my $profile = Lintian::Profile->new ('debian');
+Lintian::Data->set_vendor($profile);
+my $standards = Lintian::Data->new('standards-version/release-dates', qr/\s+/);
+my @std_list = $standards->all();
 
 my $t3_description = "This is an extension of Dist::Zilla::Plugin::InlineFiles, 
 providing the following file:
 
  - xt/release/pod-spell.t - a standard Test::Spelling test" ;
 
-@tests = (
+our @tests = (
     {
 
         # t0
         check => {
             'source Source',          "libdist-zilla-plugins-cjm-perl",
-            'source Standards-Version', "4.1.3",
+            'source Standards-Version' => $std_list[0],
             'source Build-Depends:0', "debhelper (>= 7)",
             # not really happy about the versioned dep of libmeta-cpan-perl created ex-nihilo.
             # this is a side effect of other compromises in dual dependency handling which should be harmless
@@ -34,16 +42,16 @@ providing the following file:
 
             'binary:libdist-zilla-plugins-cjm-perl Depends:0',
             '${misc:Depends}',
-            'source Vcs-Browser' ,'https://anonscm.debian.org/cgit/pkg-perl/packages/libdist-zilla-plugins-cjm-perl.git',
-            'source Vcs-Git', 'https://anonscm.debian.org/git/pkg-perl/packages/libdist-zilla-plugins-cjm-perl.git',
+            'source Vcs-Browser' ,'https://salsa.debian.org/perl-team/modules/packages/libdist-zilla-plugins-cjm-perl',
+            'source Vcs-Git', 'https://salsa.debian.org/perl-team/modules/packages/libdist-zilla-plugins-cjm-perl.git',
         },
-        load_warnings => [
+        log4perl_load_warnings => [ [ User => map { (warn => $_ ) } (
             qr/standards version/,
             qr/dependency/, qr/dual life/, (qr/dependency/) x 2,
             qr/libmodule-build-perl \(>= 0.360000\) \| perl \(>= 5.8.8\)/,
             qr/should be 'libmodule-build-perl \(>= 0.360000\)/,
             qr/dependency/, qr/dual life/, (qr/dependency/) x 2
-        ],
+        ) ] ],
         apply_fix => 1,
         file_contents_like => {
             'debian/control' => [
@@ -56,7 +64,6 @@ providing the following file:
 
         # t1
         check => { 'binary:seaview Recommends:0', 'clustalw', },
-        load_warnings => [ qr/standards version/, qr/dependency is deprecated/,qr/Vcs-Browser/, qr/Vcs-Svn/, qr/too long/ ],
         apply_fix => 1,
         load => 'binary:seaview Synopsis="multiplatform interface for sequence alignment"',
     },
@@ -64,21 +71,13 @@ providing the following file:
 
         # t2
         check => {
-            'binary:xserver-xorg-video-all Architecture',
-            'any',
-            'binary:xserver-xorg-video-all Depends:0',
-            '${F:XServer-Xorg-Video-Depends}',
-            'binary:xserver-xorg-video-all Depends:1',
-            '${misc:Depends}',
-            'binary:xserver-xorg-video-all Replaces:0',
-            'xserver-xorg-driver-all',
-            'binary:xserver-xorg-video-all Conflicts:0',
-            'xserver-xorg-driver-all',
+            'binary:xserver-xorg-video-all Architecture' => 'any',
+            'binary:xserver-xorg-video-all Depends:0'    => '${F:XServer-Xorg-Video-Depends}',
+            'binary:xserver-xorg-video-all Depends:1'    => '${misc:Depends}',
+            'binary:xserver-xorg-video-all Replaces:0'   => 'xserver-xorg-driver-all',
+            'binary:xserver-xorg-video-all Conflicts:0'  => 'xserver-xorg-driver-all',
         },
         apply_fix => 1,
-        load_warnings => undef, #skipped
-        dump_warnings => undef, #skipped
-        no_warnings => 1,
     },
     {
 
@@ -89,37 +88,39 @@ providing the following file:
               "Release tests for POD spelling",
             'binary:libdist-zilla-plugin-podspellingtests-perl Description' => $t3_description ,
         },
-        load_warnings => [ qr/standards version/, (qr/Vcs/) x 2, (qr/value/) x 2],
-        load => 'binary:libdist-zilla-plugin-podspellingtests-perl '.
-            'Description="'.$t3_description.'"',
+        load => 'binary:libdist-zilla-plugin-podspellingtests-perl '
+            . 'Description="'.$t3_description.'"',
         apply_fix => 1,
     },
     {
 
-        # t4
+        # t4, also checks XS-Python-Version deprecation
         check => {
             'source Priority' => 'extra',
             'source X-Python-Version' => ">= 2.3, << 2.5",
             'source Standards-Version', "3.9.8",
         },
-        load_warnings => [ qr/Standards-Version/, (qr/deprecated/) x 1 ],
+        log4perl_load_warnings => [ [
+            User =>
+            warn => qr/Standards-Version/,
+            warn => qr/deprecated/
+        ] ],
     },
     {
 
         # t5
         check => { 'source X-Python-Version' => ">= 2.3, << 2.6" },
-        load_warnings => [ (qr/deprecated/) x 1],
+        log4perl_load_warnings => [[ User => warn => qr/deprecated/ ]],
     },
     {
 
         # t6
         check => { 'source X-Python-Version' => ">= 2.3" },
-        load_warnings => [ (qr/deprecated/) x 1 ],
+        log4perl_load_warnings => [[ User => warn => qr/deprecated/ ]],
     },
     {
         name => 'sdlperl',
         load => 'source Uploaders:2="Sam Hocevar (Debian packages) <sam@zoy.org>"',
-        load_warnings => [ ( qr/Warning/) x 12 ],
         load_check => 'skip',
         check => {
             'binary:libsdl-perl Depends:2' => '${misc:Depends}',
@@ -129,41 +130,34 @@ providing the following file:
     },
     {
         name => 'libpango-perl',
-        load_warnings => [ ( qr/Warning/) x 4 ],
         verify_annotation => {
             'source Build-Depends' => "do NOT add libgtk2-perl to build-deps (see bug #554704)",
             'source Maintainer'    => "what a fine\nteam this one is",
         },
-        load_check => 'skip',
         apply_fix => 1,
     },
     {
         name => 'libwx-scintilla-perl',
-        load_warnings => [ ( qr/Warning/) x 5 ],
         apply_fix => 1,
     },
     {
-        # test for #683861
+        # test for #683861 -- dependency version check and epochs
         name => 'libmodule-metadata-perl',
-        load_warnings => [ ( qr/Warning/) x 5 ],
         apply_fix => 1,
     },
     {
-        # test for #682730
+        # test for #682730 (reduces libclass-isa-perl | perl (<< 5.10.1-13) to perl)
         name => 'libclass-meta-perl',
-        load_warnings => [ qr/dual life/,  ( qr/Vcs-Git/) x 2, qr/dual life/ ],
-         check => { 'source Build-Depends-Indep:1' => 'libclass-isa-perl | perl (<< 5.11.0)' },
+        check => { 'source Build-Depends-Indep:1' => 'libclass-isa-perl | perl (<< 5.11.0)' },
         apply_fix => 1,
     },
     {
         # test for #692849, must not warn about missing libfoo dependency
         name => 'dbg-dep',
-        load_warnings => [ ( qr/Vcs-Git/) x 2, qr/DM-Upload/ ],
     },
     {
         # test for #696768, Built-Using field
         name => 'built-using',
-        load_warnings => [ ( qr/Vcs-Git/) x 2, qr/DM-Upload/ ],
         apply_fix => 1,
     },
     {
@@ -173,7 +167,6 @@ providing the following file:
             'source Section' => 'non-free/libs',
             'source XS-Autobuild' => 'yes',
         },
-        load_warnings => [ ( qr/Vcs-Git/) x 2 ],
     },
     {
         # test for #713053,  XS-Ruby-Versions and XB-Ruby-Versions fields
@@ -184,10 +177,22 @@ providing the following file:
             'binary:libfast-xs-ruby XB-Ruby-Versions' => '${ruby:Versions}',
         },
     },
+    {
+        # test for #903905,  XS-Ruby-Versions in a package not maintained
+        # by ruby team
+        name => 'ruby-in-med-team',
+        check => {
+            'source XS-Ruby-Versions' => 'all',
+            'binary:ruby-rgfa XB-Ruby-Versions' => '${ruby:Versions}',
+        },
+    },
     {
         # test for XS-Testsuite field
         name => 'xs-testsuite',
-        load_warnings => [ qr/deprecated/  ],
+        log4perl_load_warnings => [ [
+            User => warn => qr/source Standards-Version/,
+            warn => qr/deprecated/
+        ] ],
         apply_fix => 1,
         check => {
             'source Testsuite' => 'autopkgtest-pkg-ruby',
@@ -196,7 +201,9 @@ providing the following file:
     {
         name => 'gnu-r-stuff',
         # last warning is about line too long.
-        load_warnings => [ qr/standards version/ , (qr/Vcs/) x 2 , qr/Description/],
+        log4perl_load_warnings => [[
+            User => map { (warn => $_)} qr/standards version/ , (qr/Vcs/) x 2 , qr/Description/
+        ]],
         apply_fix => 1,
         check => [
             'source Section' => 'gnu-r',
@@ -205,7 +212,6 @@ providing the following file:
     },
     {
         name => 'build-profiles',
-        load_warnings => [ qr/standards version/ ],
         apply_fix => 1,
         check => {
             'binary:pkg-config Build-Profiles' => '<!stage1>',
@@ -226,7 +232,38 @@ providing the following file:
         verify_annotation => {
             'binary:libmoosex-types-iso8601-perl Synopsis' => "not yet packaged\nRecommends",
         }
-    }
+    },
+
+    {
+        name => 'med-team',
+        log4perl_load_warnings => [ [
+            User => warn => qr/source Standards-Version/,
+            ( warn => qr/canonical/) x 2
+        ]],
+        apply_fix => 1,
+        check => {
+            'source Vcs-Git' => 'https://salsa.debian.org/med-team/abacas.git',
+            'source Vcs-Browser' => 'https://salsa.debian.org/med-team/abacas',
+        },
+    },
+    {
+        name => 'neurodebian-team',
+        apply_fix => 1,
+        check => {
+            'source Vcs-Git' => 'https://salsa.debian.org/neurodebian-team/caret-data.git',
+            'source Vcs-Browser' => 'https://salsa.debian.org/neurodebian-team/caret-data',
+        },
+    },
+    {
+        name => 'bcftools',
+        apply_fix => 1,
+        verify_annotation => {
+            'binary:bcftools Suggests:0' => "These are needed for plot-vcfstats"
+        },
+        check => {
+            'binary:bcftools Suggests:0' => "python"
+        },
+    },
 );
 
 my $cache_file = 't/model_tests.d/dependency-cache.txt';
