@@ -7,12 +7,9 @@ $conf_file_name = "copyright";
 $conf_dir       = 'debian';
 $model_to_test  = "Dpkg::Copyright";
 
-eval { require AptPkg::Config ;} ;
-$skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
-
 @tests = (
     { # t0
-        load_warnings => [ qr/Missing/, (qr/deprecated/) x 3 , ],
+        log4perl_load_warnings => [[ User => warn => qr/Missing/, (warn => qr/deprecated/) x 3 ]],
         load_check => 'skip',
         check => {
             'Files:"*" License full_license' => "[PSF LICENSE TEXT]",
@@ -25,7 +22,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
 
     { #t1
-        load_warnings => [ (qr/deprecated/) x 3 ],
+        log4perl_load_warnings => [[ User => (warn => qr/deprecated/) x 3 ]],
 
         check => {
             'License:"MPL-1.1" text'     => "[MPL-1.1 LICENSE TEXT]",
@@ -37,7 +34,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
 
     },
     { # t2
-        load_warnings => [ (qr/deprecated/) x 1 ],
+        log4perl_load_warnings => [[ User => warn => qr/deprecated/ ]],
 
         check => {
             'License:MPL-1.1 text' => "[MPL-1.1 LICENSE TEXT]",
@@ -51,8 +48,6 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
 
     # the empty license will default to 'other'
     { # t3
-        load_warnings => [ (qr/deprecated/) x 3, qr/use Expat/ ],
-
         check => {
             'Comment' => "\nHeader comment 1/2\nHeader comment 2/2",
             'Files:"*" Comment' => "\n Files * comment 1/2\nFiles * comment 2/2",
@@ -62,7 +57,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
         },
     },
     { # t4
-        load_warnings => [ (qr/deprecated/) x 1 ],
+        log4perl_load_warnings => [[ User => warn => qr/deprecated/ ]],
 
         check => {
             'Source'                       => "http:/some.where.com",
@@ -74,7 +69,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
     { #t5
 
-        load_warnings => [ (qr/deprecated/) x 3 ],
+        log4perl_load_warnings => [[ User => (warn => qr/deprecated/) x 3 ]],
         check => {
             'Files:"*" License short_name' => "LGPL-2+",
             'Source' => 'http://search.cpan.org/dist/Config-Model-CursesUI/',
@@ -85,7 +80,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
     { # t6
 
-        load_warnings => [ (qr/deprecated/) x 3 ],
+        log4perl_load_warnings => [[ User => (warn => qr/deprecated/) x 3 ]],
 
         check => {
             'Upstream-Contact:0' => 'Ignace Mouzannar <mouzannar at gmail.com>',
@@ -95,10 +90,10 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
     { # t7
         # example from CANDIDATE DEP-5 spec (nb 7)
-        load_warnings => [
-            (qr/Adding/) x 1 , qr/insecure/, qr/Format does not match/,
-            qr/trailing slash/
-        ],
+        log4perl_load_warnings => [[
+            'User',
+            map { ( warn => $_ ) } qr/Adding/, qr/insecure/, qr/Format does not match/, qr/trailing slash/
+        ]],
         load_check => 'skip',
         apply_fix => 1,
         check => { 
@@ -110,15 +105,17 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
     {
         # test nb 8
-        load_warnings => [ qr/insecure/, qr/Format does not match/, qr/many versions/ ],
         apply_fix => 1,
-        check => { 
+        check => {
             Format => "https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/", 
             'Files:"*" Copyright' => "2008, John Doe <jdoe\@example.com>\n2007, Jane Smith <jsmith\@example.org>\n2007, Joe Average <joe\@example.org>\n2007, J. Random User <jr\@users.example.com>",
         },
     },
-    {
-        load_warnings => [  qr/insecure/, qr/Format does not match/ ,qr/should not match/ ],
+    {   # t9
+        log4perl_load_warnings => [[
+            'User',
+            map { ( warn => $_ ) } qr/insecure/, qr/Format does not match/ ,qr/should not match/
+        ]],
         apply_fix => 1,
         load => 'Files~"*/share/web/static/[css|js|images]/yui/*"',
         check => {
@@ -128,7 +125,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
         },
     },
     { # t10
-        load_warnings => [ (qr/UK spelling/) x 4, (qr/deprecated/) x 2 ],
+        log4perl_load_warnings => [[ User => (warn => qr/UK spelling/) x 4, (warn => qr/deprecated/) x 2 ]],
 
         check => { 
             Format => "https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/", 
@@ -142,29 +139,30 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
 
     { # t11 Debian bug #610231
         # i.e. how to handle a file with missing info
-        load_warnings => [  qr/insecure/, qr/Format does not match/ ],
         apply_fix => 1,
         dump_errors =>  [ 
             qr/mandatory/ => 'Files:"*" Copyright="(c) foobar"',
             qr/mandatory/ => ' License:FOO text="foo bar" ! Files:"*" License short_name="FOO" '
         ],
     },
-    
+
     { # t12
-        load_warnings => [ qr/Adding/, (qr/deprecated/) x 3, ],
         load_check => 'no',
         dump_errors =>  [ 
             qr/not declared/ => 'License:Expat text="Expat license foobar"',
         ],
     },
 
-    { # t13 Debian bug #624305
-        load_warnings => [  qr/insecure/, qr/Format does not match/ ],
+    { # t13 Debian bug #624305 (parsing DEP5 copyright with a comma in the License field)
+        log4perl_load_warnings => [[ User => warn =>  qr/insecure/, warn => qr/Format does not match/ ]],
         apply_fix => 1,
     },
+
     { # t14 Debian bug #633847
         # need to change License model from Hash of leaves to hash of nodes 
-        load_warnings => [  qr/insecure/, qr/Format does not match/ ],
+        log4perl_load_warnings => [[
+            'User',
+            map { ( warn => $_ ) } (qr/comma/) x 4 , qr/insecure/, qr/Format does not match/ ]],
         apply_fix => 1,
         check => { 
             'Comment' => "On Debian systems, copies of the GNU General Public License version 1
@@ -179,39 +177,38 @@ in ‘/usr/share/common-licenses/GPL-1’.",
         lib/Bio/Graphics/Glyph/extending_arrow.pm" License short_name' => 'Perl',
             'Files:"lib/Bio/Graphics/FeatureDir.pm lib/Bio/Graphics/Glyph/pairplot.pm lib/Bio/Graphics/Glyph/generic.pm" License short_name' => "GPL-1+ or Artistic-2.0",
             'Files:lib/Bio/Graphics/Layout.pm License short_name' => "LGPL-2.1+ or Artistic-2.0",
-    } ,
-        
-    },       
-    
+        } ,
+    },
+
     {
         name => 'libpadre-plugin-perltidy-perl',
-        load_warnings => [ (qr/deprecated/) x 4  ],
-        check => { 
+        log4perl_load_warnings => [[ User => ( warn => qr/deprecated/) x 4  ]],
+        check => {
             'Files:"*" License short_name' => "Artistic or GPL-1+" ,
             'Files:"*" License-Alias' => { qw/check no value Perl/}, # deprecated but not yet removed
         },
-        wr_check => { 
+        wr_check => {
             'Files:"*" License short_name' => "Artistic or GPL-1+" ,
             'Files:"*" License-Alias' => { check => 'no' },
         },
     },
+
     {
         name => 'migrate-license-alias',
         load_check => 'skip', # missing Files: * in 2nd section
-        load_warnings => [ qr/Missing/, (qr/deprecated/) x 4  ],
-        check => { 
+        log4perl_load_warnings => [[ User => warn => qr/Missing/, ( warn => qr/deprecated/) x 4  ]],
+        check => {
             'Files:"*" License short_name' => "Artistic or GPL-1+" ,
             'Files:"*" License-Alias' => { qw/check no value Perl/},
         },
-        wr_check => { 
+        wr_check => {
             'Files:"*" License short_name' => "Artistic or GPL-1+" ,
             'Files:"*" License-Alias' => { check => 'no' },
         },
     },
     {
         name => 'oar',
-        load_warnings => [  qr/insecure/, qr/use Expat/ ],
-        no_warnings => 1,
+        log4perl_load_warnings => [[ User => warn => qr/insecure/, warn =>  qr/use Expat/ ]],
         apply_fix => 1,
 
         check => {
@@ -222,7 +219,7 @@ in ‘/usr/share/common-licenses/GPL-1’.",
     {
         # Debian bug #721832
         name => 'white-space' ,
-        load_warnings => [ (qr/deprecated/) x 1 ],
+        log4perl_load_warnings => [[ User => warn => qr/deprecated/ ]],
 
         check => {
             'License:MPL-1.1 text' => "[MPL-1.1 LICENSE TEXT]",
@@ -251,7 +248,10 @@ in ‘/usr/share/common-licenses/GPL-1’.",
         name => 'file-instead-of-files' ,
 
         # warning brought by fix of Debian #789568
-        load_warnings => [ qr/section 'File' is converted in 'Files'/ ],
+        log4perl_load_warnings => [[
+            User => warn => qr/section 'File' is converted in 'Files'/,
+            warn => qr/double entry/,
+        ]],
 
         check => {
             "Files:debian/patches/half_code_pod_errors.patch Copyright" =>
@@ -271,7 +271,6 @@ in ‘/usr/share/common-licenses/GPL-1’.",
     {
         name => 'update-from-scratch',
         update => { in => path('t/scanner/examples/pan.in') , quiet => 1 },
-        no_warnings => 1,
         check => {
             "License:GPL-2 text" => {value => undef, mode => 'custom'},
             "License:GPL-2 text" => qr/GNU/,
@@ -285,7 +284,6 @@ in ‘/usr/share/common-licenses/GPL-1’.",
     {
         name => 'moarvm-from-scratch',
         update => { in => path('t/scanner/examples/moarvm.in'), quiet => 1 },
-        no_warnings => 1,
         check => {
             'License:ISC text' => qr/Please fill/,
             'License:BSD-2-clause text' => qr/Please fill/,
@@ -301,7 +299,7 @@ in ‘/usr/share/common-licenses/GPL-1’.",
 
     { # Debian bug  #797321
         name => 'warn-MIT',
-        load_warnings => [ (qr/many versions of the MIT license/) x 2 ],
+        log4perl_load_warnings => [[ User => (warn => qr/many versions of the MIT license/) x 2 ]],
         apply_fix => 1,
         check => {
             "License:Expat text" => 'yada',
@@ -310,9 +308,10 @@ in ‘/usr/share/common-licenses/GPL-1’.",
             'Files:"a/*" License short_name' => 'MITA',
         }
     },
+
     { # Debian bug  #797322
         name => 'warn-BSD',
-        load_warnings => [ (qr/Please use BSD-x-clause/) x 3 ],
+        log4perl_load_warnings => [[ User => (warn => qr/Please use BSD-x-clause/) x 3 ]],
         apply_fix => 1,
         check => {
           'Files:"*" License short_name' => 'BSD-2-clause',
@@ -325,9 +324,9 @@ in ‘/usr/share/common-licenses/GPL-1’.",
           'License:BSD-like text' => 'yada',
         }
     },
+
     {
         name => 'unused-license',
-        load_warnings => [ (qr/deprecated/) x 3 ],
         # the unused license
         check_before_fix => {
             'License:"MPL-1.1" text'     => "[MPL-1.1 LICENSE TEXT]",
@@ -345,16 +344,15 @@ in ‘/usr/share/common-licenses/GPL-1’.",
         },
 
     },
+
     {
         name => 'by-dh-make',
         load_check => 'skip',
-#        load_warnings => [ (qr/deprecated/) x 3 ],
-
     },
+
     {
         name => 'new-perl-module',
         update => { in => path('t/scanner/examples/libtk-fontdialog.in') , quiet => 1 },
-        no_warnings => 1,
         check => {
             'Files:"*" Copyright' => qr/Slaven/,
             # check that Perl license is replaced by Artistic or GPL-1+
