@@ -7,14 +7,20 @@ $conf_file_name = "some-patch";
 $conf_dir       = 'debian/patches';
 $model_to_test  = "Dpkg::Patch";
 
-eval { require AptPkg::Config; };
-$skip = ( $@ or not -r '/etc/debian_version' ) ? 1 : 0;
-
 @tests = (
     {
         name => 'libperl5i' ,
         backend_arg => $conf_file_name,
-        load_warnings => [ qr/https protocol should/  ],
+        log4perl_load_warnings => [[
+            'User',
+            warn => "Warning in 'Bug-Debian:0' value 'http://bugs.debian.org/655329': https protocol should be used instead of http",
+            warn => "Warning in 'Bug-Debian:1' value '#124567': This field should contain an URL to Debian BTS and not just a bug number",
+            warn => "Warning in 'Bug-Debian:1' value '#124567': https protocol should be used instead of http",
+            warn => "Warning in 'Bug-Debian:1' value '#124567': Unknown host or protocol for Debian BTS",
+            warn => "Warning in 'Bug-Debian:2' value '#215476': This field should contain an URL to Debian BTS and not just a bug number",
+            warn => "Warning in 'Bug-Debian:2' value '#215476': https protocol should be used instead of http",
+            warn => "Warning in 'Bug-Debian:2' value '#215476': Unknown host or protocol for Debian BTS",
+        ]],
         apply_fix => 1 ,
         check => {
             'Synopsis' => qr/test TODO/,
